#include <stdio.h>
#include <stdlib.h>

typedef struct lista_el {

   /* Dato della cella attuale. */
   int dato;
   
   /* Puntatore all'elemento successivo nella lista */
   struct lista_el *succ;
} elemento;


/* costruisci_lista: dato un intero n,
 * legge n interi da stdin e
 * li organizza in una lista secondo
 * l'ordine di inserimento. 
 * ritorna la testa della nuova lista. 
 */
elemento *costruisci_lista ( int n )
{
   int i;
   /* testa rappresenta la testa della lista, il primo elemento inserito.
    * coda e' un puntatore all'ultimo elemento.
    * nuovo e' l'elemento che stiamo per inserire.
    */
   elemento *testa, *coda, *nuovo;
   
   /* all'inizio tutto vuoto */
   testa = coda = nuovo = NULL;

   for ( i = 0; i < n; i++ )  
   {
        /* alloco memoria per il prossimo */
        nuovo = (elemento *)malloc(sizeof(elemento));        

        /* ne leggo il campo dato da tastiera */
        scanf("%d", & ( nuovo->dato ) );
        /* inserisco in coda, quindi non ha successore. */
        nuovo->succ = NULL;

        /* la coda del passo precedente ha ora come successore
         * il nuovo elemento. */
        if ( coda != NULL ) 
           coda->succ = nuovo;
        /* e la coda avanza. */
        coda = nuovo;
 
        /* ricordiamoci che il primo elemento che inseriamo
         * e' la testa. */
        if ( testa == NULL ) 
             testa = nuovo;
   }

   return testa;
}

/* mtf_lista: data una lista in input e un valore,
 * a) cerca il valore all'interno della lista 
 * b) lo sposta in cima.
 * c) restituisce la nuova testa della lista.
 */
elemento * mtf_lista ( elemento *lista, int valore ) 
{
    /* posizione a cui trovo l'elemento. */
    int posizione = 0;
    elemento *corrente, *precedente;

    /* corrente: puntatore che scorre sulla lista nella ricerca. */
    corrente = lista;
    /* precedente mantiene il predecessore all'elemento 'corrente'. */
    precedente = NULL;

    /* NOTA: prima controlliamo che la lista non sia terminata,
     * e solo dopo dereferenziamo il puntatore per controllare
     * il valore. */
    while ( corrente != NULL && corrente->dato != valore )
    {
         posizione++;
         /* stiamo per avanzare, quindi al passo successivo
          * il predecessore sara' l'elemento corrente. */
         precedente = corrente;
         /* avanti. */
         corrente = corrente->succ;
    }

    /* sono arrivato in fondo: l'elemento non esiste. 
     * la lista non viene alterata. */
    if ( corrente == NULL ) {
         printf("NO\n");
         return lista;
    }
     
    /* stampo la posizione. */
    printf("%d\n", posizione);
    /* la lista si altera solo se non e' gia' la testa. */
    if ( precedente != NULL ) 
    {
        /* prima faccio in modo che il predecessori salti 
         * l'elemento da spostare e solo dopo faccio in modo
         * che sia la testa della lista. 
         * per fare cio', il suo successore e' il primo elemento
         * della lista attuale e restituisco 'corrente' come testa. 
         */
        precedente->succ = corrente->succ;
        corrente->succ = lista;    
    }

    return corrente;
}


int main()
{
  int n, valore;
  elemento *a = NULL;

  scanf("%d", &n); 
  a = costruisci_lista ( n );

  while ( 1 ) 
  {
     scanf("%d", &valore);
     if ( valore < 0 ) break;

     a = mtf_lista(a, valore);
  }
  

  return 0;
}
